DiagOverlay

Struct DiagOverlay 

pub struct DiagOverlay {
    pub row: usize,
    pub col_start: usize,
    pub col_end: usize,
    pub style: Style,
}
A char-column range on a document row that should be styled with an overlay (e.g. an underline for LSP diagnostics). Applied in a post-paint pass so it composes on top of syntax and selection colours.

Added in 0.5.0 for LSP diagnostic inline rendering.

Fields

row: usize

0-based document row.

col_start: usize

0-based start char-column (inclusive).

col_end: usize

0-based end char-column (exclusive).

style: Style

Style applied to cells in [col_start, col_end).